@@ -2,9 +2,10 @@ import logging
 import os
 import pathlib
 import shutil
-from typing import List
+from typing import List, Optional
 from urllib.parse import urlparse
 from urllib.request import urlopen
+
 import regex as re
 import stanza
 from bs4 import BeautifulSoup
@@ -13,7 +14,6 @@ from pelecanus import PelicanJson
 
 from texta_mlp.document import Document
 from texta_mlp.entity_mapper import EntityMapper
-from texta_mlp.exceptions import LanguageNotSupported
 from texta_mlp.utils import parse_bool_env
 
 
@@ -122,13 +122,18 @@ class MLP:
         Downloads Stanza resources if not present in resources directory.
         By default all is downloaded into data directory under package directory.
         """
+        model_types = ["depparse", "lemma", "pos", "tokenize"]
         stanza_resource_path = pathlib.Path(resource_dir) / "stanza"
-        if logger: logger.info(f"Downloading Stanza models into the directory: {str(stanza_resource_path)}")
+        if logger:
+            logger.info(f"Downloading Stanza models into the directory: {str(stanza_resource_path)}")
+
         stanza_resource_path.mkdir(parents=True, exist_ok=True)  # Create the directories with default permissions including parents.
         for language_code in supported_langs:
             # rglob is for recursive filename pattern matching, if it matches nothing
             # then the necessary files do not exist and we should download them.
-            if not list(stanza_resource_path.rglob("{}*".format(language_code))):
+            lang_dir_exists = True if list(stanza_resource_path.rglob("{}*".format(language_code))) else False
+            model_folders_exists = all([(stanza_resource_path / language_code / model_type).exists() for model_type in model_types])
+            if not (lang_dir_exists and model_folders_exists):
                 stanza.download(language_code, str(stanza_resource_path))
 
 
@@ -171,7 +176,7 @@ class MLP:
         return text
 
 
-    def detect_language(self, text: str):
+    def detect_language(self, text: str) -> Optional[str]:
         """
         Detects language of input text.
         If language not in supported list, language is defaulted or exception raised.
@@ -264,7 +269,6 @@ class MLP:
             stanza_resource_path = pathlib.Path(self.resource_dir) / "stanza"
             stanza_pipelines[lang] = stanza.Pipeline(
                 lang=lang,
-                processors=self._get_stanza_processors(lang),
                 dir=str(stanza_resource_path),
                 use_gpu=self.use_gpu,
                 logging_level=logging_level
@@ -272,18 +276,6 @@ class MLP:
         return stanza_pipelines
 
 
-    @staticmethod
-    def _get_stanza_processors(lang):
-        """
-        Returns processor options based on language and NER support in Stanza.
-        """
-        print(lang)
-        if lang in STANZA_NER_SUPPORT:
-            return "tokenize,pos,lemma,ner"
-        else:
-            return "tokenize,pos,lemma"
-
-
     def process(self, raw_text: str, analyzers: list = ["all"], lang=None):
         """
         Processes raw text.
@@ -314,7 +306,7 @@ class MLP:
         return document["text"]["lemmas"]
 
 
-    def __parse_doc_texts(self, doc_path: str, document: dict) -> list:
+    def parse_doc_texts(self, doc_path: str, document: dict) -> list:
         """
         Function for parsing text values from a nested dictionary given a field path.
         :param doc_path: Dot separated path of fields to the value we wish to parse.
@@ -323,10 +315,17 @@ class MLP:
         """
         wrapper = PelicanJson(document)
         doc_path_as_list = doc_path.split(".")
-        doc_texts = wrapper.safe_get_nested_value(doc_path_as_list, default=[])
-        doc_texts = [] if doc_texts is None else doc_texts
-        doc_texts = [doc_texts] if isinstance(doc_texts, str) else doc_texts
-        return doc_texts
+        content = wrapper.safe_get_nested_value(doc_path_as_list, default=[])
+        if content and isinstance(content, str):
+            return [content]
+        # Check that content is non-empty list and there are only stings in the list.
+        elif content and isinstance(content, list) and all([isinstance(list_content, str) for list_content in content]):
+            return content
+        # In case the field path is faulty and it gives you a dictionary instead.
+        elif isinstance(content, dict):
+            return []
+        else:
+            return []
 
 
     def process_docs(self, docs: List[dict], doc_paths: List[str], analyzers=["all"]):
@@ -342,7 +341,7 @@ class MLP:
             for doc_path in doc_paths:
                 # Traverse the (possible) nested dicts and extract their text values from it as a list of strings.
                 # Since the nested doc_path could lead to a list there are multiple pieces of text which would be needed to process.
-                doc_texts = self.__parse_doc_texts(doc_path, document)
+                doc_texts = self.parse_doc_texts(doc_path, document)
                 for raw_text in doc_texts:
                     analyzers = self._load_analyzers(analyzers, SUPPORTED_ANALYZERS)
                     doc = self.generate_document(raw_text, analyzers, document, doc_paths=doc_path)
